@@ -20,7 +20,9 @@ import requests
 API_BASE_URL = 'https://slack.com/api/{api}'
 
 
-__all__ = ['Slacker', 'Error', 'API']
+__all__ = ['Error', 'Response', 'BaseAPI', 'API', 'Auth', 'Users', 'Groups',
+           'Channels', 'Chat', 'IM', 'Search', 'Files', 'Stars', 'Emoji',
+           'OAuth', 'Slacker']
 
 
 class Error(Exception):
@@ -274,10 +276,10 @@ class OAuth(BaseAPI):
     def access(self, client_id, client_secret, code, redirect_uri=None):
         return self.post('oauth.access',
                          params={
-                            'client_id': client_id,
-                            'client_secret': client_secret,
-                            'code': code,
-                            'redirect_uri': redirect_uri
+                             'client_id': client_id,
+                             'client_secret': client_secret,
+                             'code': code,
+                             'redirect_uri': redirect_uri
                          })
 
 
